{% extends 'allianceauth/base-bs5.html' %}
{% load i18n %}
{% load static %}
{% load navactive %}

{% block page_title %}{% translate "Den Monitor" %}{% endblock %}
{% block header_nav_brand %}{% translate "Den Monitor" %}{% endblock %}

{% block extra_css %}<link rel="stylesheet" href="{% static 'holdfast/holdfast.css' %}">{% endblock %}

{% block header_nav_collapse_left %}
    {% if can_see_list %}
        <li class="nav-item"><a class="nav-link {% navactive request 'holdfast:den_dashboard' %}" href="{% url 'holdfast:den_dashboard' %}">{% translate "Dashboard" %}</a></li>
    {% endif %}
    <li class="nav-item"><a class="nav-link {% navactive request 'holdfast:den_information' %}" href="{% url 'holdfast:den_information' %}">{% translate "My Dens" %}</a></li>
    <li class="nav-item"><a class="nav-link {% navactive request 'holdfast:den_timers' %}" href="{% url 'holdfast:den_timers' %}">{% translate "Timers" %}</a></li>
    {% if can_see_list %}
        <li class="nav-item"><a class="nav-link {% navactive request 'holdfast:den_list' %}" href="{% url 'holdfast:den_list' %}">{% translate "Den List" %}</a></li>
    {% endif %}
    {% if can_view_all %}
        <li class="nav-item"><a class="nav-link {% navactive request 'holdfast:den_admin' %}" href="{% url 'holdfast:den_admin' %}">{% translate "Den Admin" %}</a></li>
    {% endif %}
{% endblock %}

{% block header_nav_collapse_right %}
    {% if can_manage %}
        <li class="nav-item"><a class="nav-link {% navactive request 'holdfast:den_settings' %}" href="{% url 'holdfast:den_settings' %}"><i class="fas fa-sliders-h"></i> {% translate "Settings" %}</a></li>
    {% endif %}
{% endblock %}

{% block content %}<div class="holdfast mb-3">{% block holdfast_content %}{% endblock %}</div>{% endblock %}
{% block extra_javascript %}<script src="{% static 'holdfast/holdfast.js' %}"></script>{% endblock %}
